#!/usr/bin/env Rscript
#
# This script produces centers, rotation matrices according
# to the Kabsch algorithm, see:
#
# http://en.wikipedia.org/wiki/Kabsch_algorithm
# http://www.personal.leeds.ac.uk/~bgy1mm/Bioinformatics/rmsd.html
#

args <- commandArgs(TRUE)
if (4 != length(args)) {
  stop("should be run: confall.R points1.csv points2.csv centers.csv rotation.csv")
}

pp1csv <- read.csv(args[1], row.names=1, header=FALSE, sep=",", comment="#")
pp2csv <- read.csv(args[2], row.names=1, header=FALSE, sep=",", comment="#")
pp1 <- as.matrix(pp1csv)
pp2 <- as.matrix(pp2csv)

pp1.dims <- attributes(pp1)$dim
pp2.dims <- attributes(pp2)$dim
if (3 != pp1.dims[2]) {
  stop("point matricces [1] should have 3 columns")
}
if (3 != pp2.dims[2]) {
  stop("point matricces [2] should have 3 columns")
}
if (pp1.dims[1] != pp2.dims[1]) {
  stop("point matricces should have the same count of rows")
}

cen1 <- apply(pp1, 2, mean)
cen2 <- apply(pp2, 2, mean)
pp1 <- pp1 - cen1
pp2 <- pp2 - cen2

amx <- crossprod(pp1, pp2)
smx <- crossprod(amx, amx)
imx <- solve(amx)

svdres <- svd(smx)
umx <- svdres$u
dmx <- diag(svdres$d)
vmx <- solve(svdres$v)

shalf <- umx %*% sqrt(dmx) %*% vmx

rmx <- shalf %*% imx

write.table(rbind(cen1, cen2), args[3], row.names=TRUE, col.names=FALSE, sep=",")
write.table(rmx, args[4], row.names=TRUE, col.names=FALSE, sep=",")




