#!/usr/bin/env perl
#
# seqload.pl module type identifier filename
#

use strict;
use Bio::DB::GenBank;
use Bio::DB::RefSeq;
use Bio::SeqIO;

if (4 != @ARGV) {
  die "should be run: seqload.pl module type identifier filename";
}

my $bpmodule = lc($ARGV[0]);
my $bptype = lc($ARGV[1]);
my $bpidentifier = $ARGV[2];
my $bpfilename = $ARGV[3];

if (("refseq" ne $bpmodule) && ("genbank" ne $bpmodule)) {
  die "unknown module, should be 'RefSeq' or 'GenBank'";
}

my $hastype = 0;
if ("gi" eq $bptype) {
  $hastype = 1;
}
if ("id" eq $bptype) {
  $hastype = 2;
}
if ("acc" eq $bptype) {
  $hastype = 3;
}
if ("version" eq $bptype) {
  $hastype = 4;
}

if (0 == $hastype) {
  die "unknown type, should be one of: gi, id, acc, version";
}

my $dbh = "";
if ("refseq" eq $bpmodule) {
  $dbh = Bio::DB::RefSeq->new;
}
if ("genbank" eq $bpmodule) {
  $dbh = Bio::DB::GenBank->new;
}


my $query = $bpidentifier;

my $seq = "";
eval {
  if (1 == $hastype) {
    $seq = $dbh->get_Seq_by_gi($query);
  }
  if (2 == $hastype) {
    $seq = $dbh->get_Seq_by_id($query);
  }
  if (3 == $hastype) {
    $seq = $dbh->get_Seq_by_acc($query);
  }
  if (4 == $hastype) {
    $seq = $dbh->get_Seq_by_version($query);
  }
  1;
} or do {
  die "can not find such sequence";
};

my $fn = ">" . $bpfilename;

if ($seq) {
  my $outfh = Bio::SeqIO->new(-file => $fn, -format => 'genbank');
  $outfh->write_seq($seq);
} else {
  warn('no such sequence');
}




