#!/usr/bin/env Rscript
#
# rotfall.R centers.csv rotation.csv 1|2 points.csv output-rotated_points.csv
#

args <- commandArgs(TRUE)
if (5 != length(args)) {
  stop("should be run: rotfall.R centers.csv rotation.csv rank(1|2) input-points.csv output-rotated_points.csv")
}

rank <- 0
if ("1" == args[3]) {
  rank <- 1
}
if ("2" == args[3]) {
  rank <- 2
}
if (0 == rank) {
  stop("rank (the 3rd parameter) should be either 1 or 2")
}

cencsv <- read.csv(args[1], row.names=1, header=FALSE, sep=",", comment="#")
rotcsv <- read.csv(args[2], row.names=1, header=FALSE, sep=",", comment="#")
centers <- as.matrix(cencsv)

cen.dims <- attributes(centers)$dim

if (2 != cen.dims[1]) {
  stop("centers matrix should have 2 rows")
}
if (3 != cen.dims[2]) {
  stop("centers matrix should have 3 columns")
}
cen <- centers[rank,]

rot <- as.matrix(rotcsv)
rot.dims <- attributes(rot)$dim
if (3 != rot.dims[1]) {
  stop("rotation matrix should have 3 rows")
}
if (3 != rot.dims[2]) {
  stop("rotation matrix should have 3 columns")
}

if (1 == rank) {
  rot <- solve(rot)
}

input.table <- read.csv(args[4], row.names=1, header=FALSE, sep=",", comment="#")
inp <- as.matrix(input.table)

interim <- apply(as.matrix(1:3), 1, function(x) inp[,x] - cen[x])
interim <- interim %*% rot

outp <- apply(as.matrix(1:3), 1, function(x) interim[,x] + cen[x])

write.table(outp, args[5], col.names=FALSE, row.names=TRUE, sep=",")



